# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from graphsenselib.ingest.tron.grpc.api import tron_api_pb2 as graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2
from graphsenselib.ingest.tron.grpc.core import chain_pb2 as graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2
from graphsenselib.ingest.tron.grpc.core import common_pb2 as graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_common__pb2
from graphsenselib.ingest.tron.grpc.core import contract_pb2 as graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2
from graphsenselib.ingest.tron.grpc.core import response_pb2 as graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2


class WalletStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BroadcastTransaction = channel.unary_unary(
                '/protocol.Wallet/BroadcastTransaction',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionReturn.FromString,
                )
        self.CreateCommonTransaction = channel.unary_unary(
                '/protocol.Wallet/CreateCommonTransaction',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.CreateAccount = channel.unary_unary(
                '/protocol.Wallet/CreateAccount',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountCreateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.CreateAccount2 = channel.unary_unary(
                '/protocol.Wallet/CreateAccount2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountCreateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.UpdateAccount = channel.unary_unary(
                '/protocol.Wallet/UpdateAccount',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountUpdateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.UpdateAccount2 = channel.unary_unary(
                '/protocol.Wallet/UpdateAccount2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountUpdateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.SetAccountId = channel.unary_unary(
                '/protocol.Wallet/SetAccountId',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.SetAccountIdContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.AccountPermissionUpdate = channel.unary_unary(
                '/protocol.Wallet/AccountPermissionUpdate',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountPermissionUpdateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.CreateTransaction = channel.unary_unary(
                '/protocol.Wallet/CreateTransaction',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.CreateTransaction2 = channel.unary_unary(
                '/protocol.Wallet/CreateTransaction2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.CreateAssetIssue = channel.unary_unary(
                '/protocol.Wallet/CreateAssetIssue',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.CreateAssetIssue2 = channel.unary_unary(
                '/protocol.Wallet/CreateAssetIssue2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.UpdateAsset = channel.unary_unary(
                '/protocol.Wallet/UpdateAsset',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateAssetContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.UpdateAsset2 = channel.unary_unary(
                '/protocol.Wallet/UpdateAsset2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateAssetContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.TransferAsset = channel.unary_unary(
                '/protocol.Wallet/TransferAsset',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferAssetContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.TransferAsset2 = channel.unary_unary(
                '/protocol.Wallet/TransferAsset2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferAssetContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.ParticipateAssetIssue = channel.unary_unary(
                '/protocol.Wallet/ParticipateAssetIssue',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ParticipateAssetIssueContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.ParticipateAssetIssue2 = channel.unary_unary(
                '/protocol.Wallet/ParticipateAssetIssue2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ParticipateAssetIssueContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.UnfreezeAsset = channel.unary_unary(
                '/protocol.Wallet/UnfreezeAsset',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeAssetContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.UnfreezeAsset2 = channel.unary_unary(
                '/protocol.Wallet/UnfreezeAsset2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeAssetContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.CreateWitness = channel.unary_unary(
                '/protocol.Wallet/CreateWitness',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessCreateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.CreateWitness2 = channel.unary_unary(
                '/protocol.Wallet/CreateWitness2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessCreateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.UpdateWitness = channel.unary_unary(
                '/protocol.Wallet/UpdateWitness',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessUpdateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.UpdateWitness2 = channel.unary_unary(
                '/protocol.Wallet/UpdateWitness2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessUpdateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.UpdateBrokerage = channel.unary_unary(
                '/protocol.Wallet/UpdateBrokerage',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateBrokerageContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.VoteWitnessAccount = channel.unary_unary(
                '/protocol.Wallet/VoteWitnessAccount',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.VoteWitnessContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.VoteWitnessAccount2 = channel.unary_unary(
                '/protocol.Wallet/VoteWitnessAccount2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.VoteWitnessContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.FreezeBalance = channel.unary_unary(
                '/protocol.Wallet/FreezeBalance',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.FreezeBalanceContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.FreezeBalance2 = channel.unary_unary(
                '/protocol.Wallet/FreezeBalance2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.FreezeBalanceContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.UnfreezeBalance = channel.unary_unary(
                '/protocol.Wallet/UnfreezeBalance',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeBalanceContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.UnfreezeBalance2 = channel.unary_unary(
                '/protocol.Wallet/UnfreezeBalance2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeBalanceContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.WithdrawBalance = channel.unary_unary(
                '/protocol.Wallet/WithdrawBalance',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WithdrawBalanceContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.WithdrawBalance2 = channel.unary_unary(
                '/protocol.Wallet/WithdrawBalance2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WithdrawBalanceContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.ProposalCreate = channel.unary_unary(
                '/protocol.Wallet/ProposalCreate',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ProposalCreateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.ProposalApprove = channel.unary_unary(
                '/protocol.Wallet/ProposalApprove',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ProposalApproveContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.ProposalDelete = channel.unary_unary(
                '/protocol.Wallet/ProposalDelete',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ProposalDeleteContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.DeployContract = channel.unary_unary(
                '/protocol.Wallet/DeployContract',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.CreateSmartContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.UpdateSetting = channel.unary_unary(
                '/protocol.Wallet/UpdateSetting',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateSettingContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.UpdateEnergyLimit = channel.unary_unary(
                '/protocol.Wallet/UpdateEnergyLimit',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateEnergyLimitContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.ClearContractABI = channel.unary_unary(
                '/protocol.Wallet/ClearContractABI',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ClearABIContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.TriggerContract = channel.unary_unary(
                '/protocol.Wallet/TriggerContract',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TriggerSmartContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.TriggerConstantContract = channel.unary_unary(
                '/protocol.Wallet/TriggerConstantContract',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TriggerSmartContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.ExchangeCreate = channel.unary_unary(
                '/protocol.Wallet/ExchangeCreate',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeCreateContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.ExchangeInject = channel.unary_unary(
                '/protocol.Wallet/ExchangeInject',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeInjectContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.ExchangeWithdraw = channel.unary_unary(
                '/protocol.Wallet/ExchangeWithdraw',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeWithdrawContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.ExchangeTransaction = channel.unary_unary(
                '/protocol.Wallet/ExchangeTransaction',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeTransactionContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.MarketSellAsset = channel.unary_unary(
                '/protocol.Wallet/MarketSellAsset',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.MarketSellAssetContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.MarketCancelOrder = channel.unary_unary(
                '/protocol.Wallet/MarketCancelOrder',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.MarketCancelOrderContract.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.GetNodeInfo = channel.unary_unary(
                '/protocol.Wallet/GetNodeInfo',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.NodeInfo.FromString,
                )
        self.ListNodes = channel.unary_unary(
                '/protocol.Wallet/ListNodes',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.NodeList.FromString,
                )
        self.GetChainParameters = channel.unary_unary(
                '/protocol.Wallet/GetChainParameters',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ChainParameters.FromString,
                )
        self.TotalTransaction = channel.unary_unary(
                '/protocol.Wallet/TotalTransaction',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                )
        self.GetNextMaintenanceTime = channel.unary_unary(
                '/protocol.Wallet/GetNextMaintenanceTime',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                )
        self.GetTransactionSignWeight = channel.unary_unary(
                '/protocol.Wallet/GetTransactionSignWeight',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSignWeight.FromString,
                )
        self.GetTransactionApprovedList = channel.unary_unary(
                '/protocol.Wallet/GetTransactionApprovedList',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionApprovedList.FromString,
                )
        self.GetAccount = channel.unary_unary(
                '/protocol.Wallet/GetAccount',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Account.FromString,
                )
        self.GetAccountById = channel.unary_unary(
                '/protocol.Wallet/GetAccountById',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountIdMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Account.FromString,
                )
        self.GetAccountNet = channel.unary_unary(
                '/protocol.Wallet/GetAccountNet',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AccountNetMessage.FromString,
                )
        self.GetAccountResource = channel.unary_unary(
                '/protocol.Wallet/GetAccountResource',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AccountResourceMessage.FromString,
                )
        self.GetAssetIssueByAccount = channel.unary_unary(
                '/protocol.Wallet/GetAssetIssueByAccount',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.FromString,
                )
        self.GetAssetIssueByName = channel.unary_unary(
                '/protocol.Wallet/GetAssetIssueByName',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.FromString,
                )
        self.GetAssetIssueListByName = channel.unary_unary(
                '/protocol.Wallet/GetAssetIssueListByName',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.FromString,
                )
        self.GetAssetIssueById = channel.unary_unary(
                '/protocol.Wallet/GetAssetIssueById',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.FromString,
                )
        self.GetAssetIssueList = channel.unary_unary(
                '/protocol.Wallet/GetAssetIssueList',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.FromString,
                )
        self.GetPaginatedAssetIssueList = channel.unary_unary(
                '/protocol.Wallet/GetPaginatedAssetIssueList',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaginatedMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.FromString,
                )
        self.GetNowBlock = channel.unary_unary(
                '/protocol.Wallet/GetNowBlock',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Block.FromString,
                )
        self.GetNowBlock2 = channel.unary_unary(
                '/protocol.Wallet/GetNowBlock2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockExtention.FromString,
                )
        self.GetBlockByNum = channel.unary_unary(
                '/protocol.Wallet/GetBlockByNum',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Block.FromString,
                )
        self.GetBlockByNum2 = channel.unary_unary(
                '/protocol.Wallet/GetBlockByNum2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockExtention.FromString,
                )
        self.GetBlockById = channel.unary_unary(
                '/protocol.Wallet/GetBlockById',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Block.FromString,
                )
        self.GetBlockByLimitNext = channel.unary_unary(
                '/protocol.Wallet/GetBlockByLimitNext',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BlockLimit.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockList.FromString,
                )
        self.GetBlockByLimitNext2 = channel.unary_unary(
                '/protocol.Wallet/GetBlockByLimitNext2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BlockLimit.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockListExtention.FromString,
                )
        self.GetBlockByLatestNum = channel.unary_unary(
                '/protocol.Wallet/GetBlockByLatestNum',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockList.FromString,
                )
        self.GetBlockByLatestNum2 = channel.unary_unary(
                '/protocol.Wallet/GetBlockByLatestNum2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockListExtention.FromString,
                )
        self.GetTransactionCountByBlockNum = channel.unary_unary(
                '/protocol.Wallet/GetTransactionCountByBlockNum',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                )
        self.GetTransactionById = channel.unary_unary(
                '/protocol.Wallet/GetTransactionById',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.GetTransactionInfoById = channel.unary_unary(
                '/protocol.Wallet/GetTransactionInfoById',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionInfo.FromString,
                )
        self.GetTransactionInfoByBlockNum = channel.unary_unary(
                '/protocol.Wallet/GetTransactionInfoByBlockNum',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionInfoList.FromString,
                )
        self.GetContract = channel.unary_unary(
                '/protocol.Wallet/GetContract',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_common__pb2.SmartContract.FromString,
                )
        self.GetContractInfo = channel.unary_unary(
                '/protocol.Wallet/GetContractInfo',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.SmartContractDataWrapper.FromString,
                )
        self.ListWitnesses = channel.unary_unary(
                '/protocol.Wallet/ListWitnesses',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.WitnessList.FromString,
                )
        self.GetBrokerageInfo = channel.unary_unary(
                '/protocol.Wallet/GetBrokerageInfo',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                )
        self.GetRewardInfo = channel.unary_unary(
                '/protocol.Wallet/GetRewardInfo',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                )
        self.GetDelegatedResource = channel.unary_unary(
                '/protocol.Wallet/GetDelegatedResource',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DelegatedResourceMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DelegatedResourceList.FromString,
                )
        self.GetDelegatedResourceAccountIndex = channel.unary_unary(
                '/protocol.Wallet/GetDelegatedResourceAccountIndex',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DelegatedResourceAccountIndex.FromString,
                )
        self.ListProposals = channel.unary_unary(
                '/protocol.Wallet/ListProposals',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ProposalList.FromString,
                )
        self.GetProposalById = channel.unary_unary(
                '/protocol.Wallet/GetProposalById',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Proposal.FromString,
                )
        self.GetPaginatedProposalList = channel.unary_unary(
                '/protocol.Wallet/GetPaginatedProposalList',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaginatedMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ProposalList.FromString,
                )
        self.ListExchanges = channel.unary_unary(
                '/protocol.Wallet/ListExchanges',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ExchangeList.FromString,
                )
        self.GetExchangeById = channel.unary_unary(
                '/protocol.Wallet/GetExchangeById',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Exchange.FromString,
                )
        self.GetPaginatedExchangeList = channel.unary_unary(
                '/protocol.Wallet/GetPaginatedExchangeList',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaginatedMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ExchangeList.FromString,
                )
        self.ScanShieldedTRC20NotesByIvk = channel.unary_unary(
                '/protocol.Wallet/ScanShieldedTRC20NotesByIvk',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.IvkDecryptTRC20Parameters.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DecryptNotesTRC20.FromString,
                )
        self.ScanShieldedTRC20NotesByOvk = channel.unary_unary(
                '/protocol.Wallet/ScanShieldedTRC20NotesByOvk',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.OvkDecryptTRC20Parameters.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DecryptNotesTRC20.FromString,
                )
        self.IsShieldedTRC20ContractNoteSpent = channel.unary_unary(
                '/protocol.Wallet/IsShieldedTRC20ContractNoteSpent',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NfTRC20Parameters.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.NullifierResult.FromString,
                )
        self.GetMarketOrderByAccount = channel.unary_unary(
                '/protocol.Wallet/GetMarketOrderByAccount',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderList.FromString,
                )
        self.GetMarketOrderById = channel.unary_unary(
                '/protocol.Wallet/GetMarketOrderById',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrder.FromString,
                )
        self.GetMarketPriceByPair = channel.unary_unary(
                '/protocol.Wallet/GetMarketPriceByPair',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderPair.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketPriceList.FromString,
                )
        self.GetMarketOrderListByPair = channel.unary_unary(
                '/protocol.Wallet/GetMarketOrderListByPair',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderPair.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderList.FromString,
                )
        self.GetMarketPairList = channel.unary_unary(
                '/protocol.Wallet/GetMarketPairList',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderPairList.FromString,
                )
        self.GetTransactionSign = channel.unary_unary(
                '/protocol.Wallet/GetTransactionSign',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSign.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.GetTransactionSign2 = channel.unary_unary(
                '/protocol.Wallet/GetTransactionSign2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSign.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.EasyTransferAsset = channel.unary_unary(
                '/protocol.Wallet/EasyTransferAsset',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferAssetMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.FromString,
                )
        self.EasyTransferAssetByPrivate = channel.unary_unary(
                '/protocol.Wallet/EasyTransferAssetByPrivate',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferAssetByPrivateMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.FromString,
                )
        self.EasyTransfer = channel.unary_unary(
                '/protocol.Wallet/EasyTransfer',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.FromString,
                )
        self.EasyTransferByPrivate = channel.unary_unary(
                '/protocol.Wallet/EasyTransferByPrivate',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferByPrivateMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.FromString,
                )
        self.CreateAddress = channel.unary_unary(
                '/protocol.Wallet/CreateAddress',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                )
        self.GenerateAddress = channel.unary_unary(
                '/protocol.Wallet/GenerateAddress',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AddressPrKeyPairMessage.FromString,
                )
        self.AddSign = channel.unary_unary(
                '/protocol.Wallet/AddSign',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSign.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
                )
        self.GetSpendingKey = channel.unary_unary(
                '/protocol.Wallet/GetSpendingKey',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                )
        self.GetExpandedSpendingKey = channel.unary_unary(
                '/protocol.Wallet/GetExpandedSpendingKey',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ExpandedSpendingKeyMessage.FromString,
                )
        self.GetAkFromAsk = channel.unary_unary(
                '/protocol.Wallet/GetAkFromAsk',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                )
        self.GetNkFromNsk = channel.unary_unary(
                '/protocol.Wallet/GetNkFromNsk',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                )
        self.GetIncomingViewingKey = channel.unary_unary(
                '/protocol.Wallet/GetIncomingViewingKey',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ViewingKeyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.IncomingViewingKeyMessage.FromString,
                )
        self.GetDiversifier = channel.unary_unary(
                '/protocol.Wallet/GetDiversifier',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.DiversifierMessage.FromString,
                )
        self.GetZenPaymentAddress = channel.unary_unary(
                '/protocol.Wallet/GetZenPaymentAddress',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.IncomingViewingKeyDiversifierMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaymentAddressMessage.FromString,
                )
        self.GetNewShieldedAddress = channel.unary_unary(
                '/protocol.Wallet/GetNewShieldedAddress',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedAddressInfo.FromString,
                )
        self.GetRcm = channel.unary_unary(
                '/protocol.Wallet/GetRcm',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                )
        self.CreateShieldedContractParameters = channel.unary_unary(
                '/protocol.Wallet/CreateShieldedContractParameters',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PrivateShieldedTRC20Parameters.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedTRC20Parameters.FromString,
                )
        self.CreateShieldedContractParametersWithoutAsk = channel.unary_unary(
                '/protocol.Wallet/CreateShieldedContractParametersWithoutAsk',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PrivateShieldedTRC20ParametersWithoutAsk.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedTRC20Parameters.FromString,
                )
        self.GetTriggerInputForShieldedTRC20Contract = channel.unary_unary(
                '/protocol.Wallet/GetTriggerInputForShieldedTRC20Contract',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedTRC20TriggerContractParameters.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                )


class WalletServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BroadcastTransaction(self, request, context):
        """Transactions:
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCommonTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAccount2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccount2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccountId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AccountPermissionUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTransaction2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAssetIssue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAssetIssue2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAsset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAsset2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransferAsset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TransferAsset2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ParticipateAssetIssue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ParticipateAssetIssue2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnfreezeAsset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnfreezeAsset2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWitness(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWitness2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWitness(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWitness2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBrokerage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VoteWitnessAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VoteWitnessAccount2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FreezeBalance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FreezeBalance2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnfreezeBalance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnfreezeBalance2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawBalance(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawBalance2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProposalCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProposalApprove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProposalDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeployContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSetting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnergyLimit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearContractABI(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TriggerConstantContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExchangeCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExchangeInject(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExchangeWithdraw(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExchangeTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarketSellAsset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarketCancelOrder(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNodeInfo(self, request, context):
        """The real APIs:
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNodes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChainParameters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalTransaction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNextMaintenanceTime(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionSignWeight(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionApprovedList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccount(self, request, context):
        """FLAW: Although the parameters' type is changed, it is still bad API design.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountNet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAccountResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueByAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueListByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAssetIssueList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPaginatedAssetIssueList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNowBlock(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNowBlock2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByNum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByNum2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockById(self, request, context):
        """NOTE: `GetBlockById2` is missing. The closest is `GetBlockByLatestNum2`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByLimitNext(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByLimitNext2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByLatestNum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByLatestNum2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionCountByBlockNum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionInfoById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionInfoByBlockNum(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContractInfo(self, request, context):
        """FLAW: Abusing of `info`. Should be a `GetContractCode`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListWitnesses(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBrokerageInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRewardInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegatedResource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDelegatedResourceAccountIndex(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListProposals(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetProposalById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPaginatedProposalList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListExchanges(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExchangeById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPaginatedExchangeList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanShieldedTRC20NotesByIvk(self, request, context):
        """Shielded helpers:
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ScanShieldedTRC20NotesByOvk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsShieldedTRC20ContractNoteSpent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketOrderByAccount(self, request, context):
        """Market API:
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketOrderById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketPriceByPair(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketOrderListByPair(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMarketPairList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionSign(self, request, context):
        """FLAW: Unsafe junk.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionSign2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EasyTransferAsset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EasyTransferAssetByPrivate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EasyTransfer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EasyTransferByPrivate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenerateAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddSign(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSpendingKey(self, request, context):
        """FLAW: Unsafe shielded junk(should be implemented offline).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExpandedSpendingKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAkFromAsk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNkFromNsk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIncomingViewingKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDiversifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetZenPaymentAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNewShieldedAddress(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRcm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateShieldedContractParameters(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateShieldedContractParametersWithoutAsk(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTriggerInputForShieldedTRC20Contract(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WalletServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BroadcastTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.BroadcastTransaction,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionReturn.SerializeToString,
            ),
            'CreateCommonTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCommonTransaction,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'CreateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccount,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountCreateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'CreateAccount2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAccount2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountCreateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'UpdateAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccount,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountUpdateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'UpdateAccount2': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccount2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountUpdateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'SetAccountId': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccountId,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.SetAccountIdContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'AccountPermissionUpdate': grpc.unary_unary_rpc_method_handler(
                    servicer.AccountPermissionUpdate,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountPermissionUpdateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'CreateTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTransaction,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'CreateTransaction2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTransaction2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'CreateAssetIssue': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAssetIssue,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'CreateAssetIssue2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAssetIssue2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'UpdateAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAsset,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateAssetContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'UpdateAsset2': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAsset2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateAssetContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'TransferAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.TransferAsset,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferAssetContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'TransferAsset2': grpc.unary_unary_rpc_method_handler(
                    servicer.TransferAsset2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferAssetContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'ParticipateAssetIssue': grpc.unary_unary_rpc_method_handler(
                    servicer.ParticipateAssetIssue,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ParticipateAssetIssueContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'ParticipateAssetIssue2': grpc.unary_unary_rpc_method_handler(
                    servicer.ParticipateAssetIssue2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ParticipateAssetIssueContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'UnfreezeAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.UnfreezeAsset,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeAssetContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'UnfreezeAsset2': grpc.unary_unary_rpc_method_handler(
                    servicer.UnfreezeAsset2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeAssetContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'CreateWitness': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWitness,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessCreateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'CreateWitness2': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWitness2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessCreateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'UpdateWitness': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWitness,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessUpdateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'UpdateWitness2': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWitness2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessUpdateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'UpdateBrokerage': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBrokerage,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateBrokerageContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'VoteWitnessAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.VoteWitnessAccount,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.VoteWitnessContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'VoteWitnessAccount2': grpc.unary_unary_rpc_method_handler(
                    servicer.VoteWitnessAccount2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.VoteWitnessContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'FreezeBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.FreezeBalance,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.FreezeBalanceContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'FreezeBalance2': grpc.unary_unary_rpc_method_handler(
                    servicer.FreezeBalance2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.FreezeBalanceContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'UnfreezeBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.UnfreezeBalance,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeBalanceContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'UnfreezeBalance2': grpc.unary_unary_rpc_method_handler(
                    servicer.UnfreezeBalance2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeBalanceContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'WithdrawBalance': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawBalance,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WithdrawBalanceContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'WithdrawBalance2': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawBalance2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WithdrawBalanceContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'ProposalCreate': grpc.unary_unary_rpc_method_handler(
                    servicer.ProposalCreate,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ProposalCreateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'ProposalApprove': grpc.unary_unary_rpc_method_handler(
                    servicer.ProposalApprove,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ProposalApproveContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'ProposalDelete': grpc.unary_unary_rpc_method_handler(
                    servicer.ProposalDelete,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ProposalDeleteContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'DeployContract': grpc.unary_unary_rpc_method_handler(
                    servicer.DeployContract,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.CreateSmartContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'UpdateSetting': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSetting,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateSettingContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'UpdateEnergyLimit': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnergyLimit,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateEnergyLimitContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'ClearContractABI': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearContractABI,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ClearABIContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'TriggerContract': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerContract,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TriggerSmartContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'TriggerConstantContract': grpc.unary_unary_rpc_method_handler(
                    servicer.TriggerConstantContract,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TriggerSmartContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'ExchangeCreate': grpc.unary_unary_rpc_method_handler(
                    servicer.ExchangeCreate,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeCreateContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'ExchangeInject': grpc.unary_unary_rpc_method_handler(
                    servicer.ExchangeInject,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeInjectContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'ExchangeWithdraw': grpc.unary_unary_rpc_method_handler(
                    servicer.ExchangeWithdraw,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeWithdrawContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'ExchangeTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.ExchangeTransaction,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeTransactionContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'MarketSellAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.MarketSellAsset,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.MarketSellAssetContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'MarketCancelOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.MarketCancelOrder,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.MarketCancelOrderContract.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'GetNodeInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNodeInfo,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.NodeInfo.SerializeToString,
            ),
            'ListNodes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNodes,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.NodeList.SerializeToString,
            ),
            'GetChainParameters': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChainParameters,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ChainParameters.SerializeToString,
            ),
            'TotalTransaction': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalTransaction,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            ),
            'GetNextMaintenanceTime': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNextMaintenanceTime,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            ),
            'GetTransactionSignWeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionSignWeight,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSignWeight.SerializeToString,
            ),
            'GetTransactionApprovedList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionApprovedList,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionApprovedList.SerializeToString,
            ),
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Account.SerializeToString,
            ),
            'GetAccountById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountById,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountIdMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Account.SerializeToString,
            ),
            'GetAccountNet': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountNet,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AccountNetMessage.SerializeToString,
            ),
            'GetAccountResource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountResource,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AccountResourceMessage.SerializeToString,
            ),
            'GetAssetIssueByAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueByAccount,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.SerializeToString,
            ),
            'GetAssetIssueByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueByName,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.SerializeToString,
            ),
            'GetAssetIssueListByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueListByName,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.SerializeToString,
            ),
            'GetAssetIssueById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueById,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.SerializeToString,
            ),
            'GetAssetIssueList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAssetIssueList,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.SerializeToString,
            ),
            'GetPaginatedAssetIssueList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPaginatedAssetIssueList,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaginatedMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.SerializeToString,
            ),
            'GetNowBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNowBlock,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Block.SerializeToString,
            ),
            'GetNowBlock2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNowBlock2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockExtention.SerializeToString,
            ),
            'GetBlockByNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByNum,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Block.SerializeToString,
            ),
            'GetBlockByNum2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByNum2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockExtention.SerializeToString,
            ),
            'GetBlockById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockById,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Block.SerializeToString,
            ),
            'GetBlockByLimitNext': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByLimitNext,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BlockLimit.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockList.SerializeToString,
            ),
            'GetBlockByLimitNext2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByLimitNext2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BlockLimit.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockListExtention.SerializeToString,
            ),
            'GetBlockByLatestNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByLatestNum,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockList.SerializeToString,
            ),
            'GetBlockByLatestNum2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByLatestNum2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockListExtention.SerializeToString,
            ),
            'GetTransactionCountByBlockNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionCountByBlockNum,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            ),
            'GetTransactionById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionById,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'GetTransactionInfoById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionInfoById,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionInfo.SerializeToString,
            ),
            'GetTransactionInfoByBlockNum': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionInfoByBlockNum,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionInfoList.SerializeToString,
            ),
            'GetContract': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContract,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_common__pb2.SmartContract.SerializeToString,
            ),
            'GetContractInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContractInfo,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.SmartContractDataWrapper.SerializeToString,
            ),
            'ListWitnesses': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWitnesses,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.WitnessList.SerializeToString,
            ),
            'GetBrokerageInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBrokerageInfo,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            ),
            'GetRewardInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRewardInfo,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            ),
            'GetDelegatedResource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegatedResource,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DelegatedResourceMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DelegatedResourceList.SerializeToString,
            ),
            'GetDelegatedResourceAccountIndex': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDelegatedResourceAccountIndex,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DelegatedResourceAccountIndex.SerializeToString,
            ),
            'ListProposals': grpc.unary_unary_rpc_method_handler(
                    servicer.ListProposals,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ProposalList.SerializeToString,
            ),
            'GetProposalById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetProposalById,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Proposal.SerializeToString,
            ),
            'GetPaginatedProposalList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPaginatedProposalList,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaginatedMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ProposalList.SerializeToString,
            ),
            'ListExchanges': grpc.unary_unary_rpc_method_handler(
                    servicer.ListExchanges,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ExchangeList.SerializeToString,
            ),
            'GetExchangeById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExchangeById,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Exchange.SerializeToString,
            ),
            'GetPaginatedExchangeList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPaginatedExchangeList,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaginatedMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ExchangeList.SerializeToString,
            ),
            'ScanShieldedTRC20NotesByIvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanShieldedTRC20NotesByIvk,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.IvkDecryptTRC20Parameters.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DecryptNotesTRC20.SerializeToString,
            ),
            'ScanShieldedTRC20NotesByOvk': grpc.unary_unary_rpc_method_handler(
                    servicer.ScanShieldedTRC20NotesByOvk,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.OvkDecryptTRC20Parameters.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DecryptNotesTRC20.SerializeToString,
            ),
            'IsShieldedTRC20ContractNoteSpent': grpc.unary_unary_rpc_method_handler(
                    servicer.IsShieldedTRC20ContractNoteSpent,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NfTRC20Parameters.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.NullifierResult.SerializeToString,
            ),
            'GetMarketOrderByAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketOrderByAccount,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderList.SerializeToString,
            ),
            'GetMarketOrderById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketOrderById,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrder.SerializeToString,
            ),
            'GetMarketPriceByPair': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketPriceByPair,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderPair.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketPriceList.SerializeToString,
            ),
            'GetMarketOrderListByPair': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketOrderListByPair,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderPair.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderList.SerializeToString,
            ),
            'GetMarketPairList': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMarketPairList,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderPairList.SerializeToString,
            ),
            'GetTransactionSign': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionSign,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSign.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'GetTransactionSign2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionSign2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSign.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'EasyTransferAsset': grpc.unary_unary_rpc_method_handler(
                    servicer.EasyTransferAsset,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferAssetMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.SerializeToString,
            ),
            'EasyTransferAssetByPrivate': grpc.unary_unary_rpc_method_handler(
                    servicer.EasyTransferAssetByPrivate,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferAssetByPrivateMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.SerializeToString,
            ),
            'EasyTransfer': grpc.unary_unary_rpc_method_handler(
                    servicer.EasyTransfer,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.SerializeToString,
            ),
            'EasyTransferByPrivate': grpc.unary_unary_rpc_method_handler(
                    servicer.EasyTransferByPrivate,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferByPrivateMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.SerializeToString,
            ),
            'CreateAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAddress,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            ),
            'GenerateAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.GenerateAddress,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AddressPrKeyPairMessage.SerializeToString,
            ),
            'AddSign': grpc.unary_unary_rpc_method_handler(
                    servicer.AddSign,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSign.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.SerializeToString,
            ),
            'GetSpendingKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSpendingKey,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            ),
            'GetExpandedSpendingKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExpandedSpendingKey,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ExpandedSpendingKeyMessage.SerializeToString,
            ),
            'GetAkFromAsk': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAkFromAsk,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            ),
            'GetNkFromNsk': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNkFromNsk,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            ),
            'GetIncomingViewingKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIncomingViewingKey,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ViewingKeyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.IncomingViewingKeyMessage.SerializeToString,
            ),
            'GetDiversifier': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDiversifier,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.DiversifierMessage.SerializeToString,
            ),
            'GetZenPaymentAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.GetZenPaymentAddress,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.IncomingViewingKeyDiversifierMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaymentAddressMessage.SerializeToString,
            ),
            'GetNewShieldedAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNewShieldedAddress,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedAddressInfo.SerializeToString,
            ),
            'GetRcm': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRcm,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            ),
            'CreateShieldedContractParameters': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateShieldedContractParameters,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PrivateShieldedTRC20Parameters.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedTRC20Parameters.SerializeToString,
            ),
            'CreateShieldedContractParametersWithoutAsk': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateShieldedContractParametersWithoutAsk,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PrivateShieldedTRC20ParametersWithoutAsk.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedTRC20Parameters.SerializeToString,
            ),
            'GetTriggerInputForShieldedTRC20Contract': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTriggerInputForShieldedTRC20Contract,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedTRC20TriggerContractParameters.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protocol.Wallet', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Wallet(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BroadcastTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/BroadcastTransaction',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionReturn.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCommonTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateCommonTransaction',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateAccount',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountCreateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAccount2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateAccount2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountCreateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UpdateAccount',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountUpdateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccount2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UpdateAccount2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountUpdateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccountId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/SetAccountId',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.SetAccountIdContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AccountPermissionUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/AccountPermissionUpdate',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AccountPermissionUpdateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateTransaction',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTransaction2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateTransaction2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAssetIssue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateAssetIssue',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAssetIssue2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateAssetIssue2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UpdateAsset',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateAssetContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAsset2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UpdateAsset2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateAssetContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TransferAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/TransferAsset',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferAssetContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TransferAsset2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/TransferAsset2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TransferAssetContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ParticipateAssetIssue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ParticipateAssetIssue',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ParticipateAssetIssueContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ParticipateAssetIssue2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ParticipateAssetIssue2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ParticipateAssetIssueContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnfreezeAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UnfreezeAsset',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeAssetContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnfreezeAsset2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UnfreezeAsset2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeAssetContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWitness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateWitness',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessCreateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWitness2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateWitness2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessCreateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWitness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UpdateWitness',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessUpdateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWitness2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UpdateWitness2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WitnessUpdateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBrokerage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UpdateBrokerage',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateBrokerageContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VoteWitnessAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/VoteWitnessAccount',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.VoteWitnessContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VoteWitnessAccount2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/VoteWitnessAccount2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.VoteWitnessContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FreezeBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/FreezeBalance',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.FreezeBalanceContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FreezeBalance2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/FreezeBalance2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.FreezeBalanceContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnfreezeBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UnfreezeBalance',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeBalanceContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnfreezeBalance2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UnfreezeBalance2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UnfreezeBalanceContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WithdrawBalance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/WithdrawBalance',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WithdrawBalanceContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WithdrawBalance2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/WithdrawBalance2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.WithdrawBalanceContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProposalCreate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ProposalCreate',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ProposalCreateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProposalApprove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ProposalApprove',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ProposalApproveContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProposalDelete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ProposalDelete',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ProposalDeleteContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeployContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/DeployContract',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.CreateSmartContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSetting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UpdateSetting',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateSettingContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnergyLimit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/UpdateEnergyLimit',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.UpdateEnergyLimitContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearContractABI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ClearContractABI',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ClearABIContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/TriggerContract',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TriggerSmartContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TriggerConstantContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/TriggerConstantContract',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.TriggerSmartContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExchangeCreate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ExchangeCreate',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeCreateContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExchangeInject(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ExchangeInject',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeInjectContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExchangeWithdraw(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ExchangeWithdraw',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeWithdrawContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExchangeTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ExchangeTransaction',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.ExchangeTransactionContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarketSellAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/MarketSellAsset',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.MarketSellAssetContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarketCancelOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/MarketCancelOrder',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.MarketCancelOrderContract.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNodeInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetNodeInfo',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.NodeInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNodes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ListNodes',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.NodeList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChainParameters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetChainParameters',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ChainParameters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalTransaction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/TotalTransaction',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNextMaintenanceTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetNextMaintenanceTime',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionSignWeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetTransactionSignWeight',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSignWeight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionApprovedList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetTransactionApprovedList',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionApprovedList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetAccount',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccountById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetAccountById',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountIdMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccountNet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetAccountNet',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AccountNetMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAccountResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetAccountResource',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AccountResourceMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAssetIssueByAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetAssetIssueByAccount',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAssetIssueByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetAssetIssueByName',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAssetIssueListByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetAssetIssueListByName',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAssetIssueById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetAssetIssueById',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_contract__pb2.AssetIssueContract.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAssetIssueList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetAssetIssueList',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPaginatedAssetIssueList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetPaginatedAssetIssueList',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaginatedMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AssetIssueList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNowBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetNowBlock',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Block.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNowBlock2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetNowBlock2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockByNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetBlockByNum',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Block.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockByNum2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetBlockByNum2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetBlockById',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Block.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockByLimitNext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetBlockByLimitNext',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BlockLimit.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockByLimitNext2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetBlockByLimitNext2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BlockLimit.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockListExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockByLatestNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetBlockByLatestNum',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockByLatestNum2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetBlockByLatestNum2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockListExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionCountByBlockNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetTransactionCountByBlockNum',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetTransactionById',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionInfoById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetTransactionInfoById',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionInfoByBlockNum(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetTransactionInfoByBlockNum',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionInfoList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetContract',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_common__pb2.SmartContract.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContractInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetContractInfo',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.SmartContractDataWrapper.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListWitnesses(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ListWitnesses',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.WitnessList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBrokerageInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetBrokerageInfo',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRewardInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetRewardInfo',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDelegatedResource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetDelegatedResource',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DelegatedResourceMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DelegatedResourceList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDelegatedResourceAccountIndex(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetDelegatedResourceAccountIndex',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DelegatedResourceAccountIndex.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListProposals(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ListProposals',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ProposalList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetProposalById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetProposalById',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Proposal.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPaginatedProposalList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetPaginatedProposalList',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaginatedMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ProposalList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListExchanges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ListExchanges',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ExchangeList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExchangeById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetExchangeById',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Exchange.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPaginatedExchangeList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetPaginatedExchangeList',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaginatedMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.ExchangeList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ScanShieldedTRC20NotesByIvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ScanShieldedTRC20NotesByIvk',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.IvkDecryptTRC20Parameters.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DecryptNotesTRC20.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ScanShieldedTRC20NotesByOvk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/ScanShieldedTRC20NotesByOvk',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.OvkDecryptTRC20Parameters.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.DecryptNotesTRC20.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsShieldedTRC20ContractNoteSpent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/IsShieldedTRC20ContractNoteSpent',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NfTRC20Parameters.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.NullifierResult.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMarketOrderByAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetMarketOrderByAccount',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMarketOrderById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetMarketOrderById',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrder.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMarketPriceByPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetMarketPriceByPair',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderPair.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketPriceList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMarketOrderListByPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetMarketOrderListByPair',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderPair.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMarketPairList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetMarketPairList',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.MarketOrderPairList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionSign(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetTransactionSign',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSign.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionSign2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetTransactionSign2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSign.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EasyTransferAsset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/EasyTransferAsset',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferAssetMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EasyTransferAssetByPrivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/EasyTransferAssetByPrivate',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferAssetByPrivateMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EasyTransfer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/EasyTransfer',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EasyTransferByPrivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/EasyTransferByPrivate',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EasyTransferByPrivateMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.EasyTransferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateAddress',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GenerateAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GenerateAddress',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.AddressPrKeyPairMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddSign(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/AddSign',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionSign.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.TransactionExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSpendingKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetSpendingKey',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExpandedSpendingKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetExpandedSpendingKey',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ExpandedSpendingKeyMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAkFromAsk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetAkFromAsk',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNkFromNsk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetNkFromNsk',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIncomingViewingKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetIncomingViewingKey',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ViewingKeyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.IncomingViewingKeyMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDiversifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetDiversifier',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.DiversifierMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetZenPaymentAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetZenPaymentAddress',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.IncomingViewingKeyDiversifierMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PaymentAddressMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNewShieldedAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetNewShieldedAddress',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedAddressInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRcm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetRcm',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateShieldedContractParameters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateShieldedContractParameters',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PrivateShieldedTRC20Parameters.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedTRC20Parameters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateShieldedContractParametersWithoutAsk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/CreateShieldedContractParametersWithoutAsk',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.PrivateShieldedTRC20ParametersWithoutAsk.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedTRC20Parameters.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTriggerInputForShieldedTRC20Contract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.Wallet/GetTriggerInputForShieldedTRC20Contract',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.ShieldedTRC20TriggerContractParameters.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class WalletSolidityStub(object):
    """NOTE: All other solidified APIs are useless.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccount = channel.unary_unary(
                '/protocol.WalletSolidity/GetAccount',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Account.FromString,
                )
        self.GetNowBlock2 = channel.unary_unary(
                '/protocol.WalletSolidity/GetNowBlock2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockExtention.FromString,
                )
        self.GetBlockByLatestNum2 = channel.unary_unary(
                '/protocol.WalletSolidity/GetBlockByLatestNum2',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockListExtention.FromString,
                )
        self.GetTransactionById = channel.unary_unary(
                '/protocol.WalletSolidity/GetTransactionById',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
                )
        self.GetRewardInfo = channel.unary_unary(
                '/protocol.WalletSolidity/GetRewardInfo',
                request_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
                response_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                )


class WalletSolidityServicer(object):
    """NOTE: All other solidified APIs are useless.
    """

    def GetAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNowBlock2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockByLatestNum2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRewardInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WalletSolidityServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Account.SerializeToString,
            ),
            'GetNowBlock2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNowBlock2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockExtention.SerializeToString,
            ),
            'GetBlockByLatestNum2': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockByLatestNum2,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockListExtention.SerializeToString,
            ),
            'GetTransactionById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionById,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.SerializeToString,
            ),
            'GetRewardInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRewardInfo,
                    request_deserializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.FromString,
                    response_serializer=graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protocol.WalletSolidity', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WalletSolidity(object):
    """NOTE: All other solidified APIs are useless.
    """

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.WalletSolidity/GetAccount',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.AccountAddressMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.Account.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNowBlock2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.WalletSolidity/GetNowBlock2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.EmptyMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockByLatestNum2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.WalletSolidity/GetBlockByLatestNum2',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_response__pb2.BlockListExtention.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.WalletSolidity/GetTransactionById',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_core_dot_chain__pb2.Transaction.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRewardInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protocol.WalletSolidity/GetRewardInfo',
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.BytesMessage.SerializeToString,
            graphsenselib_dot_ingest_dot_tron_dot_grpc_dot_api_dot_tron__api__pb2.NumberMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
